==> aTunes_1.11.2.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/handlers/DragAndDropHandler.java <==
/*
 * aTunes 1.11.2
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.handlers;

import net.sourceforge.atunes.kernel.modules.draganddrop.PlayListToDeviceDragAndDropListener;
import net.sourceforge.atunes.kernel.modules.draganddrop.TreesToPlayListDragAndDropListener;

public class DragAndDropHandler {

	/**
	 * Singleton instance
	 */
	private static DragAndDropHandler instance;

	/**
	 * Default constructor
	 */
	private DragAndDropHandler() {
		// Nothing to do
	}

	/**
	 * Returns singleton instance
	 * 
	 * @return
	 */
	static DragAndDropHandler getInstance() {
		if (instance == null) {
			instance = new DragAndDropHandler();
		}
		return instance;
	}

	/**
	 * Register all drag and drop listeners defined
	 */
	void registerListeners() {
		new TreesToPlayListDragAndDropListener();
		new PlayListToDeviceDragAndDropListener();
	}

}

==> aTunes_1.12.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/handlers/DragAndDropHandler.java <==
/*
 * aTunes 1.12.0
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.handlers;

import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.modules.draganddrop.PlayListTableTransferHandler;
import net.sourceforge.atunes.kernel.modules.draganddrop.PlayListToDeviceDragAndDropListener;

public class DragAndDropHandler {

	/**
	 * Singleton instance
	 */
	private static DragAndDropHandler instance;

	/**
	 * Default constructor
	 */
	private DragAndDropHandler() {
		// Nothing to do
	}

	/**
	 * Returns singleton instance
	 * 
	 * @return
	 */
	static DragAndDropHandler getInstance() {
		if (instance == null) {
			instance = new DragAndDropHandler();
		}
		return instance;
	}

	/**
	 * Register all drag and drop listeners defined
	 */
	void registerTransferHandlers() {
		PlayListTableTransferHandler playListTransferHandler = new PlayListTableTransferHandler();
		ControllerProxy.getInstance().getPlayListController().getMainPlayListTable().setTransferHandler(playListTransferHandler);
		ControllerProxy.getInstance().getPlayListController().getMainPlayListScrollPane().setTransferHandler(playListTransferHandler);

		new PlayListToDeviceDragAndDropListener();
	}

}
